@@ -122,15 +122,22 @@ void interface_main_view_destroy( MainView *main ) {
 GtkWidget *show_rec_line(GtkWidget *sizer, char *label, char *txt, int row, int col) {
 	GtkWidget *textentry;
 #if MAEMO_VERSION_MAJOR < 5
-	gtk_table_attach_defaults(GTK_TABLE(sizer), gtk_label_new(label), col, col+1, row, row+1);
+	if (label != NULL) {
+		gtk_table_attach_defaults(GTK_TABLE(sizer), gtk_label_new(label), col, col+1, row, row+1);
+	}
 	textentry=gtk_entry_new();
 	gtk_table_attach_defaults(GTK_TABLE(sizer), textentry, col+1,col+2, row, row+1);
 #else
 	textentry=hildon_entry_new(HILDON_SIZE_AUTO);
-	hildon_entry_set_placeholder(HILDON_ENTRY(textentry), label);
+	if (label != NULL) {
+		hildon_entry_set_placeholder(HILDON_ENTRY(textentry), label);
+	}
 	gtk_table_attach_defaults(GTK_TABLE(sizer), textentry, col,col+2, row, row+1);
 #endif
-	if (txt!=NULL) gtk_entry_set_text(GTK_ENTRY(textentry), txt);
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(textentry), HILDON_GTK_INPUT_MODE_FULL);
+	if (txt!=NULL) {
+		gtk_entry_set_text(GTK_ENTRY(textentry), txt);
+	}
 	return textentry;
 }
 
@@ -147,9 +154,12 @@ gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType) {
 	gchar *result=NULL;
 #if MAEMO_VERSION_MAJOR >= 5
 	GtkWidget *image;
+#else
+	GtkWidget *cancelButton;
 #endif
 	GtkWidget *contentArea;
 	GtkWidget *actionArea;
+	GtkWidget *table;
 
 	pwUi = g_new0(PasswordUI, 1);
 	pwUi->type = pwdDlgType;
@@ -157,78 +167,63 @@ gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType) {
 	pwUi->result = NULL;
 	pwUi->msg = NULL;
 	
-	pwUi->dialog = gtk_dialog_new_with_buttons(caption, GTK_WINDOW(main->data->main_view), GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, NULL);
+	pwUi->dialog = gtk_dialog_new_with_buttons(caption, GTK_WINDOW(main->data->main_view), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, NULL);
+	table = gtk_table_new(pwdDlgType, 2, TRUE);
+
 #if MAEMO_VERSION_MAJOR < 5
 	actionArea = GTK_DIALOG(pwUi->dialog)->action_area;
 	contentArea = GTK_DIALOG(pwUi->dialog)->vbox;
 
 	pwUi->button = gtk_button_new_from_stock(GTK_STOCK_OK);
-	pwUi->entry1=gtk_entry_new();
+	cancelButton = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
 #else
 	actionArea = gtk_dialog_get_action_area(GTK_DIALOG(pwUi->dialog));
 	contentArea = gtk_dialog_get_content_area(GTK_DIALOG(pwUi->dialog));
 
 	pwUi->button =  hildon_button_new_with_text(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, _("OK"), NULL);
-	image = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	hildon_button_set_image (HILDON_BUTTON (pwUi->button), image);
 	pwUi->entry1=hildon_entry_new(HILDON_SIZE_AUTO);
 #endif
 	gtk_container_add (GTK_CONTAINER (actionArea), pwUi->button);
-	gtk_container_add (GTK_CONTAINER (contentArea), pwUi->entry1);
+#if MAEMO_VERSION_MAJOR < 5
+	gtk_container_add (GTK_CONTAINER (actionArea), cancelButton);
+	g_signal_connect (cancelButton, "clicked", G_CALLBACK (callback_pwdialog_cancel), pwUi);
+#endif
+	gtk_container_add (GTK_CONTAINER (contentArea), table);
 
 	gtk_widget_set_sensitive(pwUi->button, FALSE);
 	g_signal_connect (pwUi->button, "clicked", G_CALLBACK (callback_pwdialog_button), pwUi);
 
-	gtk_entry_set_visibility(GTK_ENTRY(pwUi->entry1), FALSE);
-	g_signal_connect(G_OBJECT(pwUi->entry1), "changed", G_CALLBACK(callback_pwdialog_changed), pwUi);
-	g_signal_connect(G_OBJECT(pwUi->entry1), "activate", G_CALLBACK(callback_pwdialog_activate), pwUi);
 	if (pwdDlgType != PWD_DLG_GET) {
-#if MAEMO_VERSION_MAJOR < 5
-		pwUi->entry2=gtk_entry_new();
-#else
-		pwUi->entry2=hildon_entry_new(HILDON_SIZE_AUTO);
-#endif
-		gtk_entry_set_visibility(GTK_ENTRY(pwUi->entry2), FALSE);
-		gtk_container_add (GTK_CONTAINER (contentArea), pwUi->entry2);
-		g_signal_connect(G_OBJECT(pwUi->entry2), "changed", G_CALLBACK(callback_pwdialog_changed), pwUi);
-		g_signal_connect(G_OBJECT(pwUi->entry2), "activate", G_CALLBACK(callback_pwdialog_activate), pwUi);
 		if (pwdDlgType != PWD_DLG_NEW) {
-#if MAEMO_VERSION_MAJOR < 5
-			pwUi->entry3=gtk_entry_new();
-#else
-			pwUi->entry3=hildon_entry_new(HILDON_SIZE_AUTO);
-#endif
+			pwUi->entry1=show_rec_line(table, _("Old password"), NULL, 0, 0);
+			pwUi->entry2=show_rec_line(table,  _("New password"), NULL, 1, 0);
+			pwUi->entry3=show_rec_line(table, _("Confirm new password"), NULL, 2, 0);
 			gtk_entry_set_visibility(GTK_ENTRY(pwUi->entry3), FALSE);
-#if MAEMO_VERSION_MAJOR < 5
-#else
-			hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry1), _("Old password"));
-			hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry2), _("New password"));
-			hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry3), "Confirm new password");
-#endif
-			gtk_container_add (GTK_CONTAINER (contentArea), pwUi->entry3);
 			g_signal_connect(G_OBJECT(pwUi->entry3), "changed", G_CALLBACK(callback_pwdialog_changed), pwUi);
 			g_signal_connect(G_OBJECT(pwUi->entry3), "activate", G_CALLBACK(callback_pwdialog_activate), pwUi);
 		} else {
-#if MAEMO_VERSION_MAJOR < 5
-#else
-			hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry1), _("Password"));
-			hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry2), _("Confirm password"));
-#endif
+			pwUi->entry1=show_rec_line(table,  _("Password"), NULL, 0, 0);
+			pwUi->entry2=show_rec_line(table, _("Confirm password"), NULL, 1, 0);
 		}
+		gtk_entry_set_visibility(GTK_ENTRY(pwUi->entry2), FALSE);
+		g_signal_connect(G_OBJECT(pwUi->entry2), "changed", G_CALLBACK(callback_pwdialog_changed), pwUi);
+		g_signal_connect(G_OBJECT(pwUi->entry2), "activate", G_CALLBACK(callback_pwdialog_activate), pwUi);
 	} else {
-#if MAEMO_VERSION_MAJOR < 5
-#else
-		hildon_entry_set_placeholder(HILDON_ENTRY(pwUi->entry1), _("Password"));
-#endif
+		pwUi->entry1=show_rec_line(table, _("Password"), NULL, 0, 0);
 	}
+	gtk_entry_set_visibility(GTK_ENTRY(pwUi->entry1), FALSE);
+	g_signal_connect(G_OBJECT(pwUi->entry1), "changed", G_CALLBACK(callback_pwdialog_changed), pwUi);
+	g_signal_connect(G_OBJECT(pwUi->entry1), "activate", G_CALLBACK(callback_pwdialog_activate), pwUi);
+
 	gtk_widget_show_all(GTK_WIDGET(pwUi->dialog));
-	gtk_dialog_run(GTK_DIALOG(pwUi->dialog));
-	
-	// Getting out of the password Dialog
-	if (pwUi->result != NULL) {
-		result = g_strdup(pwUi->result);
-		g_free(pwUi->result);
+	if (GTK_RESPONSE_OK == gtk_dialog_run(GTK_DIALOG(pwUi->dialog))) {
+		// Getting out of the password Dialog
+		if (pwUi->result != NULL) {
+			result = g_strdup(pwUi->result);
+			g_free(pwUi->result);
+		}
 	}
+	
 	g_free(pwUi);
 	gtk_widget_destroy (GTK_WIDGET (pwUi->dialog));
 	return result;
@@ -249,7 +244,7 @@ gboolean fillCombo (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, G
 	return FALSE;
 }
 
-void show_rec(MainView *main, rec *r) {
+void show_rec(MainView *main, rec *r, gboolean create) {
 	GtkWidget *sizer, *scrollwindow;
 #if MAEMO_VERSION_MAJOR >= 5
 	GtkWidget *selector;
@@ -260,13 +255,16 @@ void show_rec(MainView *main, rec *r) {
 	if (main->rec_win!=NULL) return; /* don't show two rec windows at once */
 	rec_win=g_malloc0(sizeof(RecWindow));
 	main->rec_win=rec_win;
+	rec_win->create=create;
 	rec_win->rec=r;
 	rec_win->dialog = gtk_dialog_new_with_buttons (_("Edit/View Entry"), GTK_WINDOW(main->data->main_view), GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, GTK_STOCK_OK, 1, _("Copy User"), 2, _("Copy Pwd"), 3, NULL);
 	rec_win->delete_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), GTK_STOCK_DELETE, 4);
 	rec_win->edit_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), _("Edit"), 5);
 /*	gtk_button_set_image(GTK_BUTTON(rec_win->edit_button), GTK_STOCK_EDIT); */
 #if MAEMO_VERSION_MAJOR < 5
-	g_object_set(rec_win->dialog, "content-area-border", 1, "button_spacing", 20, NULL);
+	gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	// "content-area-border", 1 : Bug 9163
+	g_object_set(rec_win->dialog, "button_spacing", 20, NULL);
 #endif
     /*  where's "button-spacing", "content-area-border", "action_area_border" ? - not in scratchbox, maybe on n800 */
 	g_signal_connect(rec_win->dialog, "response", G_CALLBACK ( callback_rec_response), main);
@@ -345,19 +343,27 @@ gboolean addEntryToGroup(GtkTreeStore *store, GtkTreeIter *groupIter, rec *data)
 gboolean searchGroup (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, SearchGroup *sg) {
 	rec *data;
 	gchar *label;
+	gchar *group;
 	
 	gtk_tree_model_get(model, iter, LABEL_COLUMN, &label, DATA_COLUMN, &data,  -1);
-	if (data == NULL && label != NULL && g_ascii_strcasecmp( emptynull(sg->data->group), label) == 0) {
+	if (sg->data->group == NULL || sg->data->group[0] == '\0') {
+		group = g_strdup(_(DEFAULT_GROUP));
+	} else {
+		group = g_strdup(sg->data->group);
+	}
+	if (data == NULL && label != NULL && g_ascii_strcasecmp(group, label) == 0) {
 		sg->found = addEntryToGroup(GTK_TREE_STORE(model), iter, sg->data);
-		
+		g_free(group);
 		return TRUE;
 	}
+	g_free(group);
 	return FALSE;
 }
 
 gboolean addEntryToTree(MainView *main, rec *data) {
 	SearchGroup *sg;
 	GtkTreeIter groupIter;
+	gchar *group;
 	
 	sg = g_new0(SearchGroup, 1);
 	sg->data = data;
@@ -370,7 +376,17 @@ gboolean addEntryToTree(MainView *main, rec *data) {
 	
 	//Create the group 
 	gtk_tree_store_append(main->store, &groupIter, NULL);
-	gtk_tree_store_set(main->store, &groupIter, LABEL_COLUMN, emptynull(data->group), ICON_COLUMN, GTK_STOCK_DIRECTORY, DATA_COLUMN, NULL, -1);
+	
+	if (data->group == NULL || data->group[0] == '\0') {
+		group = g_strdup(_(DEFAULT_GROUP));
+	} else {
+		group = g_strdup(data->group);
+	}
+	gtk_tree_store_set(main->store, &groupIter, LABEL_COLUMN, group, ICON_COLUMN, GTK_STOCK_DIRECTORY, DATA_COLUMN, NULL, GROUP_COLUMN, FALSE, -1);
+	
+	if (main->currentGroup == NULL && data->group != NULL) {
+		main->currentGroup = g_strdup(data->group);
+	}
 	
 	//Add the Entry
 	addEntryToGroup(main->store, &groupIter, data);
@@ -604,14 +620,6 @@ void interface_show_state(MainView *main) {
 	interface_show_item(main->add_item, fopen);
 	
 	if (GTK_IS_WIDGET(main->add_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
-#if MAEMO_VERSION_MAJOR < 5
-		gtk_widget_set_sensitive(GTK_WIDGET(main->new_tb), !fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->open_tb), !fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->close_tb), fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->save_tb), fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->saveas_tb), fopen);
-#endif
-		gtk_widget_set_sensitive(GTK_WIDGET(main->change_password_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->add_tb), fopen);
 		gtk_editable_set_editable(GTK_EDITABLE(main->filter_tb), fopen);
 		if (!fopen) {
@@ -652,19 +660,8 @@ static void create_toolbar ( MainView *main ) {
 
 	/* Make menus and buttons to toolbar: */
 	/* Create toolitems using defined items from stock */
-#if MAEMO_VERSION_MAJOR < 5
-	main->new_tb = gtk_tool_button_new_from_stock(GTK_STOCK_NEW);
-	main->open_tb = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
-	main->close_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CLOSE);
-	main->save_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
-	main->saveas_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE_AS);
-	main->separator_tb1 = gtk_separator_tool_item_new();
-	main->fullscreen_tb = gtk_tool_button_new_from_stock( GTK_STOCK_ZOOM_FIT );
-    main->separator_tb3 = gtk_separator_tool_item_new();
-#endif
 	main->add_tb = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
-	main->change_password_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CONVERT);
-	main->separator_tb2 = gtk_separator_tool_item_new();
+	main->separator_tb = gtk_separator_tool_item_new();
     
     /* create filter text entry in a container */
     main->filter_item_tb = gtk_tool_item_new();
@@ -676,38 +673,15 @@ static void create_toolbar ( MainView *main ) {
     hildon_entry_set_placeholder (HILDON_ENTRY (main->filter_tb), _("Filter"));
 #endif
 
-    /* gtk_entry_set_max_length( GTK_ENTRY(main->filter_tb) , (gint) 24);  */
     gtk_container_add( GTK_CONTAINER( main->filter_item_tb ) , main->filter_tb);
 	
     /* Insert items to toolbar */
-#if MAEMO_VERSION_MAJOR < 5
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->new_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->open_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->close_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->save_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->saveas_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb1, -1);
-#endif
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->add_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->change_password_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb2, -1);
-#if MAEMO_VERSION_MAJOR < 5
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->fullscreen_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb3, -1);
-#endif
+	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->filter_item_tb, -1);
 
 	/* Connect signals to buttons */
-#if MAEMO_VERSION_MAJOR < 5
-	g_signal_connect(G_OBJECT(main->new_tb), "clicked", G_CALLBACK(callback_file_new), main);
-	g_signal_connect(G_OBJECT(main->open_tb), "clicked", G_CALLBACK(callback_file_open), main);
-	g_signal_connect(G_OBJECT(main->close_tb), "clicked", G_CALLBACK(callback_file_close), main);
-	g_signal_connect(G_OBJECT(main->save_tb), "clicked", G_CALLBACK(callback_file_save), main);
-	g_signal_connect(G_OBJECT(main->saveas_tb), "clicked", G_CALLBACK(callback_file_saveas), main);
-	g_signal_connect(G_OBJECT(main->fullscreen_tb), "clicked", G_CALLBACK(callback_fullscreen), main);
-#endif
 	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
-	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
 	g_signal_connect(G_OBJECT(main->filter_tb), "changed", G_CALLBACK(callback_filter), main);
 	
 	/* Attach toolbar to main view */
@@ -725,11 +699,8 @@ void create_textarea( MainView *main ) {
 	GtkTreeSelection *select;
 		
 	main->font_desc = pango_font_description_from_string ("Nokia Sans 16");
-	main->store=gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+	main->store=gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 	main->treeView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(main->store));
-#if MAEMO_VERSION_MAJOR >= 5
-	gtk_tree_view_set_show_expanders(GTK_TREE_VIEW (main->treeView), TRUE);
-#endif
 	renderer = gtk_cell_renderer_pixbuf_new();
 	column = gtk_tree_view_column_new_with_attributes (_("Icon"), renderer, "stock-id", ICON_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (main->treeView), column);
@@ -742,13 +713,14 @@ void create_textarea( MainView *main ) {
         select = gtk_tree_view_get_selection (GTK_TREE_VIEW (main->treeView));
         gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
         gtk_tree_view_columns_autosize(GTK_TREE_VIEW(main->treeView));
-				
+	
     /* Connect signals */
 #if MAEMO_VERSION_MAJOR >= 5
 	g_signal_connect (G_OBJECT(main->treeView), "hildon-row-tapped", G_CALLBACK (callback_hildon_activate_treeView), main);
 #else
 	g_signal_connect (G_OBJECT(main->treeView), "row-activated", G_CALLBACK (callback_activate_treeView), main);
 #endif
+g_signal_connect (G_OBJECT(main->treeView), "key-press-event", G_CALLBACK (callback_tree_key_pressed), main);
 }
 
 /* toggle fullscreen */
