@@ -40,7 +40,11 @@
 
 #include <src/appdata.h>
 
-#define _(String) gettext(String)
+//#define _(String) gettext(String)
+//#include <libintl.h>
+#include <locale.h>
+#include <glib/gi18n.h>
+
 
 /* confirmation responses */
 #define CONFRESP_YES 1
@@ -56,6 +60,8 @@
 
 #define MAIN_VIEW_NAME ""
 
+#define DEFAULT_GROUP "Default Group"
+
 #define MCE_MATCH_RULE "type='signal',interface='" MCE_SIGNAL_IF "',member='" MCE_INACTIVITY_SIG "'"
 
 typedef enum {
@@ -69,12 +75,14 @@ typedef enum {
 	LABEL_COLUMN,
 	ICON_COLUMN,
 	DATA_COLUMN,
+	GROUP_COLUMN,
 	N_COLUMNS
 } PwsafeColumns;
 
 typedef struct RecWindow {
 	rec *rec;
 	gboolean editable;
+	gboolean create;
 	GtkWidget *dialog;
 	GtkWidget *title;
 	GtkWidget *group;
@@ -117,19 +125,10 @@ struct _MainView
 	/* Toolbar */
 	GtkWidget* toolbar;
 	GtkWidget* iconw;
-	GtkToolItem* new_tb;
-	GtkToolItem* open_tb;
-	GtkToolItem* close_tb;
-	GtkToolItem* save_tb;
-	GtkToolItem* saveas_tb;
-	GtkToolItem* separator_tb1;
 	GtkToolItem* add_tb;
-	GtkToolItem* change_password_tb;
-	GtkToolItem* separator_tb2;
-	GtkToolItem* fullscreen_tb;
-    GtkToolItem* separator_tb3;
-    GtkToolItem* filter_item_tb;
-    GtkWidget* filter_tb;
+	GtkToolItem* separator_tb;
+	GtkToolItem* filter_item_tb;
+	GtkWidget* filter_tb;
 
 	GtkWidget* mainwindow;
 
@@ -141,6 +140,7 @@ struct _MainView
 	gboolean file_edited;		/* tells is our file on view edited */
 	gchar* file_name;
 	gchar *last_file;
+	gchar *currentGroup;
 	gchar* pass;			/* must be stored to be able to write file again... */
 	gchar *preferences;		/* preferences from the file... just written back out. */
 	RecWindow* rec_win;		/*active recwindow object... one per app */
@@ -171,7 +171,7 @@ gint interface_yes_no_note(MainView * main, gchar *title);
 void interface_error( PwsafeError me, MainView *main );
 void msgbox(MainView* main, char *msg);
 void populate_treeView (MainView *main);
-void show_rec(MainView *main, rec *record);
+void show_rec(MainView *main, rec *record, gboolean create);
 void empty_treeView(MainView *main);
 void unshow_rec(MainView *main);
 gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType);
